==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/it.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Cose da fare",
    "{actor} created calendar {calendar}" : "{actor} ha creato il calendario {calendar}",
    "You created calendar {calendar}" : "Hai creato il calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha eliminato il calendario {calendar}",
    "You deleted calendar {calendar}" : "Hai eliminato il calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha aggiornato il calendario {calendar}",
    "You updated calendar {calendar}" : "Hai aggiornato il calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha condiviso il calendario {calendar} con te",
    "You shared calendar {calendar} with {user}" : "Hai condiviso il calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha aggiornato il calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha rimosso la condivisione del calendario {calendar} con te",
    "You unshared calendar {calendar} from {user}" : "Hai rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha rimosso la condivisione del calendario {calendar} con se stesso",
    "You shared calendar {calendar} with group {group}" : "Hai condiviso il calendario {calendar} con il gruppo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha condiviso il calendario {calendar} con il gruppo {group}",
    "You unshared calendar {calendar} from group {group}" : "Hai rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creato l'evento {event} nel calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Hai creato l'evento {event} nel calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha eliminato l'evento {event} dal calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Hai ha eliminato l'evento {event} dal calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha aggiornato l'evento {event} nel calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Hai aggiornato l'evento {event} nel calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ha creato la cosa da fare {todo} nell'elenco {calendar}",
    "You created todo {todo} in list {calendar}" : "Hai creato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} ha eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Hai eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ha aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "You updated todo {todo} in list {calendar}" : "Hai aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ha risolto la cosa da fare {todo} nell'elenco {calendar}",
    "You solved todo {todo} in list {calendar}" : "Hai risolto la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Hai riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> è stato modificato",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario è stato modificato",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>cosa da fare</strong> del calendario è stata modificata",
    "Contact birthdays" : "Date di nascita dei contatti",
    "Personal" : "Personale",
    "Contacts" : "Contatti",
    "WebDAV" : "WebDAV",
    "Technical details" : "Dettagli tecnici",
    "Remote Address: %s" : "Indirizzo remoto: %s",
    "Request ID: %s" : "ID richiesta: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/it.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Calendario",
    "Todos" : "Cose da fare",
    "Personal" : "Personale",
    "{actor} created calendar {calendar}" : "{actor} ha creato il calendario {calendar}",
    "You created calendar {calendar}" : "Hai creato il calendario {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ha eliminato il calendario {calendar}",
    "You deleted calendar {calendar}" : "Hai eliminato il calendario {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ha aggiornato il calendario {calendar}",
    "You updated calendar {calendar}" : "Hai aggiornato il calendario {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} ha condiviso il calendario {calendar} con te",
    "You shared calendar {calendar} with {user}" : "Hai condiviso il calendario {calendar} con {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ha aggiornato il calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} ha rimosso la condivisione del calendario {calendar} con te",
    "You unshared calendar {calendar} from {user}" : "Hai rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ha rimosso la condivisione del calendario {calendar} con {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ha rimosso la condivisione del calendario {calendar} con se stesso",
    "You shared calendar {calendar} with group {group}" : "Hai condiviso il calendario {calendar} con il gruppo {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} ha condiviso il calendario {calendar} con il gruppo {group}",
    "You unshared calendar {calendar} from group {group}" : "Hai rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} ha rimosso la condivisione del calendario {calendar} con il gruppo {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} ha creato l'evento {event} nel calendario {calendar}",
    "You created event {event} in calendar {calendar}" : "Hai creato l'evento {event} nel calendario {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ha eliminato l'evento {event} dal calendario {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Hai ha eliminato l'evento {event} dal calendario {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ha aggiornato l'evento {event} nel calendario {calendar}",
    "You updated event {event} in calendar {calendar}" : "Hai aggiornato l'evento {event} nel calendario {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} ha creato la cosa da fare {todo} nell'elenco {calendar}",
    "You created todo {todo} in list {calendar}" : "Hai creato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} ha eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Hai eliminato la cosa da fare {todo} dall'elenco {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} ha aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "You updated todo {todo} in list {calendar}" : "Hai aggiornato la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} ha risolto la cosa da fare {todo} nell'elenco {calendar}",
    "You solved todo {todo} in list {calendar}" : "Hai risolto la cosa da fare {todo} nell'elenco {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} ha riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Hai riaperto la cosa da fare {todo} nell'elenco {calendar}",
    "A <strong>calendar</strong> was modified" : "Un <strong>calendario</strong> è stato modificato",
    "A calendar <strong>event</strong> was modified" : "Un <strong>evento</strong> del calendario è stato modificato",
    "A calendar <strong>todo</strong> was modified" : "Una <strong>cosa da fare</strong> del calendario è stata modificata",
    "Contact birthdays" : "Date di nascita dei contatti",
    "%s via %s" : "%s tramite %s",
    "Invitation canceled" : "Invito annullato",
    "Hello %s," : "Ciao %s,",
    "The meeting »%s« with %s was canceled." : "L'incontro «%s» con %s è stato annullato.",
    "Invitation updated" : "Invito aggiornato",
    "The meeting »%s« with %s was updated." : "L'incontro «%s» con %s è stato aggiornato.",
    "%s invited you to »%s«" : "%s ti ha invitato a «%s»",
    "When:" : "Quando:",
    "Where:" : "Dove:",
    "Description:" : "Descrizione:",
    "Link:" : "Collegamento:",
    "Contacts" : "Contatti",
    "Technical details" : "Dettagli tecnici",
    "Remote Address: %s" : "Indirizzo remoto: %s",
    "Request ID: %s" : "ID richiesta: %s",
    "CalDAV server" : "Server CalDAV",
    "Send invitations to attendees" : "Invia gli inviti ai partecipanti",
    "Please make sure to properly set up the email settings above." : "Assicurati di configurare correttamente le impostazioni di posta sopra."
},
"nplurals=2; plural=(n != 1);");
